@@ -27,7 +27,7 @@ ROTATE_COUNT = 5000
 from cloghandler import ConcurrentRotatingFileHandler
 
 class RotateLogStressTester:
-    def __init__(self, sharedfile, uniquefile, name="LogStressTester"):
+    def __init__(self, sharedfile, uniquefile, name="LogStressTester", logger_delay=0):
         self.sharedfile = sharedfile
         self.uniquefile = uniquefile
         self.name = name
@@ -36,12 +36,14 @@ class RotateLogStressTester:
         self.rotateCount = ROTATE_COUNT
         self.random_sleep_mode = False
         self.debug = False
+        self.logger_delay = logger_delay
     
     def getLogHandler(self, fn):
         """ Override this method if you want to test a different logging handler
         class. """
         return ConcurrentRotatingFileHandler(fn, 'a', self.rotateSize,
-                                             self.rotateCount, debug=self.debug)
+                                             self.rotateCount, delay=self.logger_delay,
+                                             debug=self.debug)
         # To run the test with the standard library's RotatingFileHandler:
         # from logging.handlers import RotatingFileHandler
         # return RotatingFileHandler(fn, 'a', self.rotateSize, self.rotateCount)
@@ -132,6 +134,10 @@ parser.add_option("--random-sleep-mode",
                   action="store_true", default=False)
 parser.add_option("--debug",
                   action="store_true", default=False)
+parser.add_option("--logger-delay",
+                  action="store_true", default=False,
+                   help="Enable the 'delay' mode in the logger class. "
+                  "This means that the log file will be opened on demand.") 
 
 
 def main_client(args):
@@ -143,7 +149,7 @@ def main_client(args):
     if os.path.isfile(client):
         sys.stderr.write("Already a client using output file %s\n" % client)
         sys.exit(1)
-    tester = RotateLogStressTester(shared, client)
+    tester = RotateLogStressTester(shared, client, logger_delay=options.logger_delay)
     tester.random_sleep_mode = options.random_sleep_mode
     tester.debug = options.debug
     tester.writeLoops = options.log_calls
@@ -231,6 +237,8 @@ def main_runner(args):
             cmdline.append("--random-sleep-mode")
         if options.debug:
             cmdline.append("--debug")
+        if options.logger_delay:
+            cmdline.append("--logger-delay")
         
         child = manager.launchPopen(cmdline)
         child.update(sharedfile=shared, clientfile=client)
